Unreleased changes
------------------



Version 0
---------

0.2.6 / 2020-09-22
~~~~~~~~~~~~~~~~~~
* Remove template artifacts
* Add Python 2.7 compatibility

0.1.0 / 2020-07-17
~~~~~~~~~~~~~~~~~~
* Project generated using the cookiecutter template from
  https://git.km3net.de/templates/python-project
